.TH Command WORK
.NA work "Use engineers to raise sector efficiency"
.LV Expert
.SY "work <UNIT> <MOBILITY>"
This command causes a unit with the engineering ability
to increase the efficiency of a sector. (see info show for
information on finding out unit abilities)
.s1
The increase in efficiency depends on mobility used. It costs a 100%
efficient land unit 6 mobility to raise a sector 1% efficiency.  Less
efficient land units are charged proportionally higher amounts of
mobility.  For example, a 50% land unit would be charged 12 mobility
to raise the efficiency of a sector by 1%.
.s1
If the sector has been re-designated, the working unit will first tear
down the old, then start working on the new effic, in the same way that
sectors update normally.
.s1
.SA "show, Unit-types, LandUnits"
