.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject MOVING
.in \w'transportXX\0\0\0\0'u
.s1
.L "fly * "
Fly planes from sector/ship to sector/ship and bomb or snoop
.L "march * "
Move a land unit or units
.L "move * "
Transport ore, civilians, guns, etc
.L "navigate * "
Move ship or fleet around
.L "transport * "
Move planes or nuclear devices around
.s1
.L "Mobility   "
How much mobility stuff costs
.L "Move * "
A quick reference for moving things around
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
