.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject COMMUNICATION
.in \w'IntroductionXX\0\0\0\0'u
.s1
.L "accept   "
Find out who's accepting what communications from whom
.L "announce * "
Send an announcement to all players
.L "country   "
Find out information about deity countries
.L "echo   "
Echo a string back to the client
.L "flash   "
Send a message directly to a friend's terminal
.L "headlines   "
Summarize the weeks events (part of \*Qnews\*U)
.L "motd   "
Print the message of the day
.L "newspaper * "
The yellow press
.L "players   "
List players currently connected to the game
.L "power * "
Display arbitrarily measured strengths of all countries
.L "pray * "
Interacting with the Deity
.L "read * "
Read your telegrams
.L "reject   "
Stop/start listening to other countries
.L "sharebmap   "
Share parts of your bmap with another country
.L "sync   "
Synchronize the client database with the server
.L "telegram * "
Send \*Qdiplomatic\*U communique to another country
.L "toggle   "
Toggle client flags
.L "wall   "
Send a message directly to all allies terminals
.L "wire * "
Read announcements
.s1
.L "Clients * "
Clients which communicate well with the Empire2 Server
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
