.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject SERVER
.in \w'CHANGES.CHAINSAWXX\0\0\0\0'u
.s1
.L "Bugs   "
Known bugs in the Empire Server
.L "CHANGES.CHAINSAW   "
Changes from KSU Empire to Chainsaw code
.L "Empire2   "
Changes from the Chainsaw server to the Empire2 Server
.L "Empire3   "
Changes from the Empire2 server to the Empire3 Server
.L "Hidden   "
The HIDDEN option
.L "History   "
Empire Revision History
.L "Merc   "
Changes from KSU code to Merc code
.L "Old-empire   "
Differences from 1.2 to UCB Empire
.L "Options   "
Server options
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
