.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject PRODUCTION
.in \w'TechnologyXX\0\0\0\0'u
.s1
.L "production * "
Predicts production of sectors at the next update
.L "start * "
Turn sector production on
.L "stop   "
Stop sector production
.s1
.L "Education   "
How Education is calculated at the update
.L "Happiness   "
How happiness is calculated at the update
.L "Products * "
Formulas for the production of commodities
.L "Quick-ref * "
A quick reference card for sector types and production
.L "Research   "
How Research level is calculated each update
.L "Technology   "
How technology level is calculated each update
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
