.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject OCCUPATION
.in \w'SectorMownershipXX\0\0\0\0'u
.s1
.L "convert * "
Change conquered civilians into uncompensated workers
.L "shoot * "
Dispose of enemy civilians or uncompensated workers
.s1
.L "Citizens * "
Work, starvation, and general management of your citizens
.L "Guerrilla   "
Guerrilla warfare
.L "Sector-ownership * "
Sector ownership
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
