.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject POPULACE
.in \w'demobilizeXX\0\0\0\0'u
.s1
.L "census * "
Report contents of sectors
.L "convert * "
Change conquered civilians into uncompensated workers
.L "demobilize * "
Change military into civilians
.L "enlist * "
Turn civilians into military
.L "explore * "
Claim unowned land
.L "shoot * "
Dispose of enemy civilians or uncompensated workers
.L "starvation * "
Find out who's going to starve
.s1
.L "Autofeed   "
How to use fishing boats to automatically feed your civs
.L "Citizens * "
Work, starvation, and general management of your citizens
.L "Food   "
How much people eat at the update
.L "Guerrilla   "
Guerrilla warfare
.L "Plague   "
The Plague
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
