.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject LANDUNITS
.in \w'MaintenanceXX\0\0\0\0'u
.s1
.L "army   "
Designate members of an \*Qarmy\*U
.L "assault * "
Attack coastal sector from ship
.L "attack * "
Sector vs sector combat
.L "board * "
Board enemy ship
.L "build * "
Build ships, planes, bridges, land units or nuclear weapons
.L "fortify * "
Fortify a land unit
.L "fuel * "
Give fuel to a ship/unit
.L "land * "
Report status of unit, army or units in a given area
.L "lcargo * "
List the commodities on board your units
.L "lload * "
Load things onto land units
.L "llookout * "
Check from units for other units, planes and/or sector types
.L "lmap   "
Map around a land unit
.L "lmine   "
Mine a sector with an engineering unit
.L "lradar   "
Use a radar unit's radar
.L "lrange   "
Edit the reaction range of a unit
.L "lretreat   "
Set retreat conditions/paths for units or armies
.L "ltend   "
Transfer things between a unit and the ship carrying it
.L "lunload * "
Unload things from land units
.L "march * "
Move a land unit or units
.L "mission * "
Assign a mission to a ship/plane/unit
.L "morale   "
Change the retreat percentage of a unit
.L "scrap * "
Scrap a ship, plane, or unit
.L "scuttle * "
Destroy a ship, plane, or unit
.L "show * "
Stats for building ships, planes, units, or bridges
.L "supply * "
Cause a unit to draw supplies
.L "work   "
Use engineers to raise sector efficiency
.s1
.L "Land-units * "
How to use land units
.L "Maintenance   "
The cost to maintain ships, planes, and land units.
.L "Mobility   "
How much mobility stuff costs
.L "Unit-types * "
Description of the different types of land units
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
