.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject SHIPS
.in \w'MaintenanceXX\0\0\0\0'u
.s1
.L "assault * "
Attack coastal sector from ship
.L "board * "
Board enemy ship
.L "build * "
Build ships, planes, bridges, land units or nuclear weapons
.L "cargo * "
List the commodities on board your ships
.L "coastwatch * "
Check from sectors for nearby ships
.L "fire * "
Fire artillery from sector/ship/unit on sector/ship
.L "fleetadd   "
Designate members of a \*Qfleet\*U
.L "follow   "
Cause one ship to automatically follow another
.L "fuel * "
Give fuel to a ship/unit
.L "load * "
Load goods, people, etc onto a ship
.L "lookout * "
Check from ships for other ships and/or sector types
.L "ltend   "
Transfer things between a unit and the ship carrying it
.L "mine * "
Drop sea mines from a ship
.L "mission * "
Assign a mission to a ship/plane/unit
.L "mquota   "
Change the mobility quota of a ship with SAIL orders
.L "name   "
Give a name to a ship
.L "navigate * "
Move ship or fleet around
.L "order   "
Order a ship to auto-navigate
.L "payoff   "
Find out the current payoff of a trade ship
.L "qorder   "
Query the auto-navigation orders of a ship
.L "radar * "
Perform radar scan from ship or sector
.L "retreat   "
Set retreat conditions/paths for ships or fleets
.L "sail   "
Give sailing orders to a ship
.L "scrap * "
Scrap a ship, plane, or unit
.L "scuttle * "
Destroy a ship, plane, or unit
.L "ship * "
Report status of ship, fleet or ships in a given area
.L "show * "
Stats for building ships, planes, units, or bridges
.L "smap * "
Get a map around a ship
.L "sonar * "
Use sonar to look for ships
.L "sorder   "
Show ship order statistical information
.L "tend * "
Transfer commodities between ships
.L "torpedo * "
Slip a torpedo to some poor sucker (from a sub or ship)
.L "unload * "
Inverse of load (above)
.L "unsail   "
Stop a ship from sailing
.L "upgrade   "
Update the tech of a ship to the current tech level
.s1
.L "Autofeed   "
How to use fishing boats to automatically feed your civs
.L "Autonav   "
Giving ships automatic sailing orders
.L "Maintenance   "
The cost to maintain ships, planes, and land units.
.L "Mobility   "
How much mobility stuff costs
.L "Ship-types * "
Description of different types of ships.
.L "Trade-ships * "
How to use trade ships
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
