/* Generated automatically from globals.c.in by configure. */
#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/client/globals.c.in,v 2.3 1995/10/16 20:54:40 empire Exp $";
#endif /* not lint */

/*
 * globals.c
 *
 * globals for the client.
 *
 * Dave Pare, 1986
 */

#include <stdio.h>
#include <setjmp.h>
#include "misc.h"
#include "fnlist.h"
#include "proto.h"

s_char	empirehost[] = "205.164.80.15";
s_char	empireport[] = "7773";

struct fn fnlist[] = {
	{ NULL,	"user",	USER,},
	{ NULL,	"coun",	COUN,},
	{ NULL,	"quit",	QUIT,},
	{ NULL,	"pass",	PASS,},
	{ NULL,	"play",	PLAY,},
	{ NULL,	"list",	LIST,},
	{ NULL,	"cmd",	CMD,},
	{ NULL,	"ctld",	CTLD,},
	{ NULL, "kill", KILL,},
	{ NULL,	"",	0,},
};
