.TH Info "List of Subjects"
.s1
Empire info is available on the following subjects:
.NF
  Combat                   LandUnits                Playing                  
  Commodities              Maps                     Populace                 
  Communication            Missions                 Production               
  Deity                    Moving                   Sectors                  
  Detection                Nation                   Server                   
  Diplomacy                Obsolete                 Ships                    
  Distribution             Occupation               Update                   
  Introduction             Planes                   
.FI
Type "info <Subject>" where <Subject> is one of the subjects listed above.
For a complete list of all info topics, type "info all".
