.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject INTRODUCTION
.in \w'IntroductionXX\0\0\0\0'u
.s1
.L "Clients * "
Clients which communicate well with the Empire2 Server
.L "Expert   "
Advice to expert Empire players
.L "Guide * "
The Empire Users Guide
.L "Hints   "
Hints to help you play Empire better
.L "Kill * "
How to kill your process on the server
.L "Novice * "
Advice for Novices
.L "Overview * "
An Overview of the Game
.L "Rules * "
The rules for playing Empire
.L "Suggestions   "
Suggestions for enhancements to the game
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
