.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject COMBAT
.in \w'HitchanceXX\0\0\0\0'u
.s1
.L "assault * "
Attack coastal sector from ship
.L "attack * "
Sector vs sector combat
.L "board * "
Board enemy ship
.L "fire * "
Fire artillery from sector/ship/unit on sector/ship
.L "paradrop   "
Attack a sector from the air
.L "spy * "
Snoop on adjacent enemy sectors
.L "strength   "
Report defensive strengths of sectors
.L "torpedo * "
Slip a torpedo to some poor sucker (from a sub or ship)
.s1
.L "Attack   "
Details for attack, assault, paradrop, and board
.L "Damage   "
How much damage stuff does
.L "Hitchance   "
The chance of a projectile hitting its target
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
