.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject DIPLOMACY
.in \w'relationsXX\0\0\0\0'u
.s1
.L "accept   "
Find out who's accepting what communications from whom
.L "declare * "
Formally declare alliance, friendly, neutrality, hostile or war
.L "power * "
Display arbitrarily measured strengths of all countries
.L "reject   "
Stop/start listening to other countries
.L "relations * "
Shows diplomatic relations between countries
.L "report * "
List all countries and their status
.L "telegram * "
Send \*Qdiplomatic\*U communique to another country
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
