.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject MISSIONS
.in \w'InterceptionXX\0\0\0\0'u
.s1
.L "Interception   "
How plane interdiction works
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
